# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/islhd/order/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/islhd/order/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Islhd\\Order\\": "packages/islhd/order/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Islhd\Order\Providers\OrderServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Order'  => Islhd\Order\Facades\Order::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Islhd\\OrderTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Islhd\Order\Providers\OrderServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Islhd\Order\Providers\OrderServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Islhd\Order\Providers\OrderServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/order/{modulename}

**User**

    http://path-to-route-folder/user/order/{modulename}

**Public**

    http://path-to-route-folder/orders


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/order/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/order/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/order/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/order/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/order/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/order/{modulename}/{slug}
    METHOD: GET