<?php

namespace Islhd\Order\Providers;

use Illuminate\Support\ServiceProvider;

class OrderServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'order');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'order');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerOrder();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerOrder()
    {
        $this->app->bind('order', function($app) {
            return new Order($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Order', 'Lavalite\Order\Facades\Order');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('islhd.order', function ($app) {
            return $this->app->make('Islhd\Order\Order');
        });

        // Bind Order to repository
        $this->app->bind(
            'Islhd\Order\Interfaces\OrderRepositoryInterface',
            \Islhd\Order\Repositories\Eloquent\OrderRepository::class
        );        // Bind Detail to repository
        $this->app->bind(
            'Islhd\Order\Interfaces\DetailRepositoryInterface',
            \Islhd\Order\Repositories\Eloquent\DetailRepository::class
        );        // Bind History to repository
        $this->app->bind(
            'Islhd\Order\Interfaces\HistoryRepositoryInterface',
            \Islhd\Order\Repositories\Eloquent\HistoryRepository::class
        );

        $this->app->register(\Islhd\Order\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Islhd\Order\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and order's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'islhd.order'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeOrder::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['islhd.order'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('islhd/order.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/order')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/order')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
