<?php

namespace Islhd\Order\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Islhd\Order\Models\Order;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Islhd\Order\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/order/order/*')) {
            Route::bind('order', function ($order) {
                $orderrepo = $this->app->make('Islhd\Order\Interfaces\OrderRepositoryInterface');
                return $orderrepo->findorNew($order);
            });
        }
        if (Request::is('*/order/detail/*')) {
            Route::bind('detail', function ($detail) {
                $detailrepo = $this->app->make('Islhd\Order\Interfaces\DetailRepositoryInterface');
                return $detailrepo->findorNew($detail);
            });
        }
        if (Request::is('*/order/history/*')) {
            Route::bind('history', function ($history) {
                $historyrepo = $this->app->make('Islhd\Order\Interfaces\HistoryRepositoryInterface');
                return $historyrepo->findorNew($history);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
